#brownieSort
A programme for sorting __brownies__ into groups (tents)
of equal size according to friendships. Brownies and
friendship choices are imported from a text file.
An algorithm is run to find the optimal (or near best)
groupings of brownies. The best camp can be printed to the screen
as a list of tents, their occupants, and the associated
happiness scores.

*in the UK, a brownie is a junior girl-guide (or junior girl-scout)*